@@ -1,4 +1,4 @@
-__version__ = '0.1.3'
+__version__ = '0.2.0'
 
 __title__ = "objectrest"
 __github_project_name__ = "objectrest"
@@ -8,4 +8,4 @@ __github_username__ = "nwithan8"
 __copyright__ = "Copyright © 2021 - Nate Harris"
 __license__ = 'GNU General Public License v3 (GPLv3)'
 __description__ = "A Python package to handle REST API requests, JSON parsing, and pydantic object generation."
-__keywords__ = ["API", "REST", "objects", "pydantic", "JSON", "requests"]
\ No newline at end of file
+__keywords__ = ["API", "REST", "objects", "pydantic", "JSON", "requests", "OAuth2", "token"]
\ No newline at end of file
